print("import: 'binstar_client'")
import binstar_client

print("import: 'binstar_client.commands'")
import binstar_client.commands

print("import: 'binstar_client.inspect_package'")
import binstar_client.inspect_package

print("import: 'binstar_client.inspect_package.tests'")
import binstar_client.inspect_package.tests

print("import: 'binstar_client.mixins'")
import binstar_client.mixins

print("import: 'binstar_client.scripts'")
import binstar_client.scripts

print("import: 'binstar_client.tests'")
import binstar_client.tests

print("import: 'binstar_client.utils'")
import binstar_client.utils

print("import: 'binstar_client.utils.notebook'")
import binstar_client.utils.notebook

print("import: 'binstar_client.utils.notebook.tests'")
import binstar_client.utils.notebook.tests

